@@ -703,10 +703,10 @@ int HafGpu_ColorConvert(AgoNode * node)
 			"  if ((gx < %d) && (gy < %d)) {\n" // (width+7)/8, (height+1)/2
 			"    pRGB_buf += pRGB_offset + (gy * %d) + (gx * 24);\n" // pRGB_stride * 2
 			"    U24x8 pRGB0, pRGB1;\n"
-			"    pRGB0.s0123 = *(__global uint4 *) pRGB_buf;\n"
-			"    pRGB0.s45 = *(__global uint2 *)&pRGB_buf[16];\n"
-			"    pRGB1.s0123 = *(__global uint4 *)&pRGB_buf[%d];\n" // pRGB_stride
-			"    pRGB1.s45 = *(__global uint2 *)&pRGB_buf[%d+16];\n" // pRGB_stride
+			"    pRGB0.s0123 = vload4(0, (__global uint *) pRGB_buf);\n"
+			"    pRGB0.s45 = vload2(0, (__global uint *)&pRGB_buf[16]);\n"
+			"    pRGB1.s0123 = vload4(0, (__global uint *)&pRGB_buf[%d]);\n" // pRGB_stride
+			"    pRGB1.s45 = vload2(0, (__global uint *)&pRGB_buf[%d+16]);\n" // pRGB_stride
 			), (width + 7) / 8, (height + 1) / 2, pRGB_stride * 2, pRGB_stride, pRGB_stride);
 		node->opencl_code += item;
 	}
@@ -721,8 +721,8 @@ int HafGpu_ColorConvert(AgoNode * node)
 			"  if ((gx < %d) && (gy < %d)) {\n" // (width+7)/8, (height+1)/2
 			"    pRGB_buf += pRGB_offset + (gy * %d) + (gx << 5);\n" // pRGB_stride * 2
 			"    U32x8 pRGBX0, pRGBX1;\n"
-			"    pRGBX0 = *(__global U32x8 *) pRGB_buf;\n"
-			"    pRGBX1 = *(__global U32x8 *)&pRGB_buf[%d];\n" // pRGB_stride
+			"    pRGBX0 = vload8(0, (__global uint *) pRGB_buf);\n"
+			"    pRGBX1 = vload8(0, (__global uint *)&pRGB_buf[%d]);\n" // pRGB_stride
 			), (width + 7) / 8, (height + 1) / 2, pRGB_stride * 2, pRGB_stride);
 		node->opencl_code += item;
 	}
@@ -1151,9 +1151,9 @@ int HafGpu_ColorConvert(AgoNode * node)
 					OPENCL_FORMAT(
 					"    pY_buf += pY_offset + (gy * %d) + (gx << 3);\n" // pY_stride * 2
 					"    pUV_buf += pUV_offset + (gy * %d) + (gx << 3);\n" // pUV_stride
-					"    *(__global U8x8 *) pY_buf = pY0;\n"
-					"    *(__global U8x8 *)&pY_buf[%d] = pY1;\n" // pY_stride
-					"    *(__global U8x8 *) pUV_buf = pUV;\n"
+					"    vstore2(pY0, 0, (__global uint *) pY_buf);\n"
+					"    vstore2(pY1, 0, (__global uint *)&pY_buf[%d]);\n" // pY_stride
+					"    vstore2(pUV, 0, (__global uint *)pUV_buf);\n"
 					), pY_stride * 2, pUV_stride, pY_stride);
 				node->opencl_code += item;
 			}
@@ -1371,10 +1371,10 @@ int HafGpu_ColorConvert(AgoNode * node)
 					"    yuv.s0 = mad(amd_unpack3(pY1.s1),r2f.s0,r2f.s1); yuv.s1 = mad(amd_unpack3(pU1.s1),r2f.s2,r2f.s3); yuv.s2 = mad(amd_unpack3(pV1.s1),r2f.s2,r2f.s3);\n"
 					"    f.s1 = mad(cR.s1, yuv.s2, yuv.s0); f.s2 = mad(cG.s0, yuv.s1, yuv.s0); f.s2 = mad(cG.s1, yuv.s2, f.s2); f.s3 = mad(cB.s0, yuv.s1, yuv.s0); pRGB1.s5 = amd_pack(trunc(f));\n"
 					"    pRGB_buf += pRGB_offset + (gy * %d) + (gx * 24);\n" // pRGB_stride * 2
-					"    *(__global uint4 *) pRGB_buf = pRGB0.s0123;\n"
-					"    *(__global uint2 *)&pRGB_buf[16] = pRGB0.s45;\n"
-					"    *(__global uint4 *)&pRGB_buf[%d] = pRGB1.s0123;\n" // pRGB_stride
-					"    *(__global uint2 *)&pRGB_buf[%d+16] = pRGB1.s45;\n" // pRGB_stride
+					"    vstore4(pRGB0.s0123, 0, (__global uint *) pRGB_buf);\n"
+					"    vstore2(pRGB0.s45, 0, (__global uint *)&pRGB_buf[16]);\n"
+					"    vstore4(pRGB1.s0123, 0, (__global uint *)&pRGB_buf[%d]);\n" // pRGB_stride
+					"    vstore2(pRGB1.s45, 0, (__global uint *)&pRGB_buf[%d+16]);\n" // pRGB_stride
 					), pRGB_stride * 2, pRGB_stride, pRGB_stride);
 			}
 			else { // VX_CHANNEL_RANGE_FULL
@@ -1414,10 +1414,10 @@ int HafGpu_ColorConvert(AgoNode * node)
 					"    yuv.s0 = amd_unpack3(pY1.s1); yuv.s1 = amd_unpack3(pU1.s1); yuv.s2 = amd_unpack3(pV1.s1); yuv.s1 -= 128.0f;; yuv.s2 -= 128.0f;\n"
 					"    f.s1 = mad(cR.s1, yuv.s2, yuv.s0); f.s2 = mad(cG.s0, yuv.s1, yuv.s0); f.s2 = mad(cG.s1, yuv.s2, f.s2); f.s3 = mad(cB.s0, yuv.s1, yuv.s0); pRGB1.s5 = amd_pack(trunc(f));\n"
 					"    pRGB_buf += pRGB_offset + (gy * %d) + (gx * 24);\n" // pRGB_stride * 2
-					"    *(__global uint4 *) pRGB_buf = pRGB0.s0123;\n"
-					"    *(__global uint2 *)&pRGB_buf[16] = pRGB0.s45;\n"
-					"    *(__global uint4 *)&pRGB_buf[%d] = pRGB1.s0123;\n" // pRGB_stride
-					"    *(__global uint2 *)&pRGB_buf[%d+16] = pRGB1.s45;\n" // pRGB_stride
+					"    vstore4(pRGB0.s0123, 0, (__global uint *) pRGB_buf);\n"
+					"    vstore2(pRGB0.s45, 0, (__global uint *)&pRGB_buf[16]);\n"
+					"    vstore4(pRGB1.s0123, 0, (__global uint *)&pRGB_buf[%d]);\n" // pRGB_stride
+					"    vstore2(pRGB1.s45, 0, (__global uint *)&pRGB_buf[%d+16]);\n" // pRGB_stride
 					), pRGB_stride * 2, pRGB_stride, pRGB_stride);
 			}
 			node->opencl_code += item;
