@@ -47,6 +47,9 @@ static vx_status VX_CALLBACK refreshNormalize(vx_node node, const vx_reference *
     vx_status status = VX_SUCCESS;
     void *roi_tensor_ptr, *roi_tensor_ptr_dst;
     int mean_stddev_array_size = 1;
+    RppSize_t numDims;
+    STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[0], VX_TENSOR_NUMBER_OF_DIMS, &numDims, sizeof(numDims)));
+    int roiDims = ((numDims == 3) && (data->inputTensorDims[2] == 1)) ? 1 : data->pSrcGenericDesc->numDims - 1;  // roiDims - For how many dims the ROI (start, end) values are needed
     if (data->deviceType == AGO_TARGET_AFFINITY_GPU) {
 #if ENABLE_OPENCL
         return VX_ERROR_NOT_IMPLEMENTED;
@@ -55,19 +58,25 @@ static vx_status VX_CALLBACK refreshNormalize(vx_node node, const vx_reference *
         STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[1], VX_TENSOR_BUFFER_HIP, &roi_tensor_ptr, sizeof(roi_tensor_ptr)));
         STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[2], VX_TENSOR_BUFFER_HIP, &data->pDst, sizeof(data->pDst)));
         STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[3], VX_TENSOR_BUFFER_HIP, &roi_tensor_ptr_dst, sizeof(roi_tensor_ptr_dst)));
+        if (!data->pSrcDims) {
+            hipError_t err = hipHostMalloc(&data->pSrcDims, data->inputTensorDims[0] * roiDims * 2, hipHostMallocDefault);
+            if (err != hipSuccess)
+                return ERRMSG(VX_ERROR_NOT_ALLOCATED, "refresh: hipHostMalloc of size %ld failed \n", data->inputTensorDims[0] * roiDims * 2);
+        }
 #endif
     } else if (data->deviceType == AGO_TARGET_AFFINITY_CPU) {
         STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[0], VX_TENSOR_BUFFER_HOST, &data->pSrc, sizeof(data->pSrc)));
         STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[1], VX_TENSOR_BUFFER_HOST, &roi_tensor_ptr, sizeof(roi_tensor_ptr)));
         STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[2], VX_TENSOR_BUFFER_HOST, &data->pDst, sizeof(data->pDst)));
         STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[3], VX_TENSOR_BUFFER_HOST, &roi_tensor_ptr_dst, sizeof(roi_tensor_ptr_dst)));
+        if (!data->pSrcDims) {
+            data->pSrcDims = new unsigned[data->inputTensorDims[0] * roiDims * 2];
+        }
     }
-    RppSize_t numDims;
-    STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[0], VX_TENSOR_NUMBER_OF_DIMS, &numDims, sizeof(numDims)));
     STATUS_ERROR_CHECK(vxQueryTensor((vx_tensor)parameters[0], VX_TENSOR_DIMS, &data->inputTensorDims, sizeof(vx_size) * numDims));
 
     // For Identifying if the input Tensor is 1D (excluding the Nth dimension) [ even if 2nd dim is 1 - The tensor is considered 1D ]
-    if ((numDims == 3) && (data->inputTensorDims[2] == 1)) {
+    if ((numDims == 3) && (data->inputTensorDims[2] == 1)) {  // For NHW/NFT/NTF layouts
         RpptROI *src_roi = reinterpret_cast<RpptROI *>(roi_tensor_ptr);
         RpptROI *dst_roi = reinterpret_cast<RpptROI *>(roi_tensor_ptr_dst);
         for (unsigned i = 0, j = 0; i < data->inputTensorDims[0]; i++, j += 2) {
@@ -77,17 +86,48 @@ static vx_status VX_CALLBACK refreshNormalize(vx_node node, const vx_reference *
             dst_roi[i].xywhROI.roiHeight = src_roi[i].xywhROI.roiHeight;
         }
         data->pSrcRoi = static_cast<unsigned *>(data->pSrcDims);
-    } else {
+    } else if (numDims == 4) {  // For NHWC/NCHW layouts
+        RpptROI *src_roi = reinterpret_cast<RpptROI *>(roi_tensor_ptr);
+        RpptROI *dst_roi = reinterpret_cast<RpptROI *>(roi_tensor_ptr_dst);
+        for (unsigned i = 0; i < data->inputTensorDims[0]; i++) {  // data->inputTensorDims[0] corresponds to batch size
+            // rocAL ROI for image formats is stored in XYWH format. Transpose kernel needs ROI for all dims so adding the channel ROI here
+            unsigned index = i * roiDims * 2;
+            if (data->inputLayout == vxTensorLayout::VX_NHWC) {
+                data->pSrcDims[index + 0] = src_roi[i].xywhROI.xy.y;       // StartH
+                data->pSrcDims[index + 1] = src_roi[i].xywhROI.xy.x;       // StartW
+                data->pSrcDims[index + 2] = 0;                             // StartC
+                data->pSrcDims[index + 3] = src_roi[i].xywhROI.roiHeight;  // EndH
+                data->pSrcDims[index + 4] = src_roi[i].xywhROI.roiWidth;   // EndW
+                data->pSrcDims[index + 5] = data->inputTensorDims[3];      // EndC - assign channel value from input dims
+            } else if (data->inputLayout == vxTensorLayout::VX_NCHW) {
+                data->pSrcDims[index + 0] = 0;                             // StartC
+                data->pSrcDims[index + 1] = src_roi[i].xywhROI.xy.y;       // StartH
+                data->pSrcDims[index + 2] = src_roi[i].xywhROI.xy.x;       // StartW
+                data->pSrcDims[index + 3] = data->inputTensorDims[1];      // EndC - assign channel value from input dims
+                data->pSrcDims[index + 4] = src_roi[i].xywhROI.roiHeight;  // EndH
+                data->pSrcDims[index + 5] = src_roi[i].xywhROI.roiWidth;   // EndW
+            }
+            dst_roi[i].xywhROI = src_roi[i].xywhROI;
+        }
+        data->pSrcRoi = static_cast<unsigned *>(data->pSrcDims);
+    } else {  // For other layouts which already has generic ROI
         data->pSrcRoi = static_cast<unsigned *>(roi_tensor_ptr);
+        Rpp32u *dst_roi = static_cast<unsigned *>(roi_tensor_ptr_dst);
+        for (unsigned i = 0; i < data->inputTensorDims[0]; i++) {  // data->inputTensorDims[0] corresponds to batch size
+            unsigned index = i * roiDims * 2;
+            for (Rpp32u j = 0; j < roiDims; j++) {
+                dst_roi[index + j + roiDims] = data->pSrcRoi[index + j + roiDims];
+            }
+        }
     }
-    int nDim = data->pSrcGenericDesc->numDims - 1;
-    Rpp32u axis[nDim];
+    Rpp32u axis[roiDims];
+    // Calculate mean_stddev_array_size to calculate the size of mean and stddev buffer passed from user
     for (unsigned i = 0; i < data->inputTensorDims[0]; i++) {
-        unsigned index = i * nDim * 2;
+        unsigned index = i * roiDims * 2;
         int totalElements = 1;
-        for (Rpp32u j = 0; j < nDim; j++) {
+        for (Rpp32u j = 0; j < roiDims; j++) {
             axis[j] = ((data->axis_mask & (int)(pow(2, j))) >= 1) ? 1 : 0;
-            totalElements *= !axis[j] ? data->pSrcRoi[index + j + nDim] : 1;
+            totalElements *= !axis[j] ? data->pSrcRoi[index + j + roiDims] : 1;
         }
         mean_stddev_array_size = std::max(mean_stddev_array_size, totalElements);
     }
@@ -173,7 +213,9 @@ static vx_status VX_CALLBACK processNormalize(vx_node node, const vx_reference *
     refreshNormalize(node, parameters, num, data);
 #if RPP_AUDIO
     if (data->deviceType == AGO_TARGET_AFFINITY_GPU) {
-#if ENABLE_HIP
+#if ENABLE_OPENCL
+        return_status = VX_ERROR_NOT_IMPLEMENTED;
+#elif ENABLE_HIP
         rpp_status = rppt_normalize_gpu(data->pSrc, data->pSrcGenericDesc, data->pDst, data->pDstGenericDesc, data->axis_mask, data->pMean, data->pStddev, data->computeMeanAndStdDev, data->scale, data->shift, data->pSrcRoi, data->handle->rppHandle);
         return_status = (rpp_status == RPP_SUCCESS) ? VX_SUCCESS : VX_FAILURE;
 #endif
@@ -221,7 +263,6 @@ static vx_status VX_CALLBACK initializeNormalize(vx_node node, const vx_referenc
         data->pDstGenericDesc->offsetInBytes = 0;
         fillGenericDescriptionPtrfromDims(data->pDstGenericDesc, data->inputLayout, data->outputTensorDims);
 
-        data->pSrcDims = new uint[data->inputTensorDims[0] * 2];
         refreshNormalize(node, parameters, num, data);
         STATUS_ERROR_CHECK(createRPPHandle(node, &data->handle, data->inputTensorDims[0], data->deviceType));
         STATUS_ERROR_CHECK(vxSetNodeAttribute(node, VX_NODE_LOCAL_DATA_PTR, &data, sizeof(data)));
@@ -247,12 +288,17 @@ static vx_status VX_CALLBACK uninitializeNormalize(vx_node node, const vx_refere
             if (err != hipSuccess)
                 std::cerr << "\n[ERR] hipHostFree failed  " << std::to_string(err) << "\n";
         }
+        if (data->pSrcDims) {
+            hipError_t err = hipHostFree(data->pSrcDims);
+            if (err != hipSuccess)
+                std::cerr << "\n[ERR] hipHostFree failed  " << std::to_string(err) << "\n";
+        }
 #endif
     } else {
         if (data->pMean) delete[] data->pMean;
         if (data->pStddev) delete[] data->pStddev;
+        if (data->pSrcDims) delete[] data->pSrcDims;
     }
-    if (data->pSrcDims) delete[] data->pSrcDims;
     if (data->pSrcGenericDesc) delete data->pSrcGenericDesc;
     if (data->pDstGenericDesc) delete data->pDstGenericDesc;
     if (data) delete data;
